**NOTE**

This project is suppose to proved an API to the Elro connects K1 adapter

The code idea is based on the the code of Bas van den Berg https://github.com/dib0/elro_connects.

Aim of this library is to provide a API for the Elro Connects P1 connector. Example code is included.

A PyPi package wil become avaiable. To be installed with:
`pip install lib-elro-connects`

lib-elro-connects might will also function on the BASE smart home gateway SWM188A and the SITERWELL GS198. Both have not been tested.

THIS CODE IS NOT READY FOR PRODUCTION YET, but let me know if you would like to help.

Kind regards,

Jan Bouwhuis

## Supported Devices by ERLO K1 connects SF40GA

### Fire alarms

- Elro FZ5002R

### Heat alarms

- Elro FH3801R

### CO alarms

- Elro FC4801R

### Water alarms

- Elro FW3801R

### Window and Door sensors

- Elro SF40MA11
